OfferAccountingType
Liefert eine Liste aller OfferAccountingType-Objekte.
GET/api/invoice/offeraccountingtypes
Query-Parameter
searchStringstring | Text, nach dem in der Liste gesucht wird |
orderFieldNamestring | Name des Bestellfelds |
orderFieldSortstring | SortiermodusErlaubt: DESCASC |
pageinteger | Seite der Liste |
pageSizeinteger | Anzahl der Einträge je Seite |
withMaxPageNumberstring | gibt die Anzahl verfügbarer Seiten als Header zurück, wenn dies gesetzt ist |
Antworten
200Liefert eine Liste aller OfferAccountingType-Objekte.array<OfferAccountingType>
Felder anzeigen (7)
idintegerPrimärschlüssel des Angebots-Buchungstyps. Interne ID.
namestringPflichtName der Buchungsart.
cancelled_namestringName, der verwendet wird, wenn ein Angebot dieses Typs storniert wird.
typestringPflichtArt des Buchungstyps, zum Beispiel Angebot oder Vertrag.
conditionsstringAuf dem Angebot abgedruckte Bedingungen.
number_descriptionstringBeschreibung des Zahlenformats des Angebots.
deletedbooleanDie Buchungsart wird gelöscht.
curl --request GET \
--url https://eure-instanz.iw-erp.de/api/invoice/offeraccountingtypes \
--header 'x-iw-jwt-token: <TOKEN>'const options = {method: 'GET', headers: {'x-iw-jwt-token': '<TOKEN>'}};
fetch('https://eure-instanz.iw-erp.de/api/invoice/offeraccountingtypes', options)
.then(res => res.json())
.then(res => console.log(res))
.catch(err => console.error(err));import requests
url = "https://eure-instanz.iw-erp.de/api/invoice/offeraccountingtypes"
headers = {"x-iw-jwt-token": "<TOKEN>"}
response = requests.get(url, headers=headers)
print(response.text)<?php
require_once('vendor/autoload.php');
$client = new \GuzzleHttp\Client();
$response = $client->request('GET', 'https://eure-instanz.iw-erp.de/api/invoice/offeraccountingtypes', [
'headers' => [
'x-iw-jwt-token' => '<TOKEN>',
],
]);
echo $response->getBody();using System.Net.Http.Headers;
var client = new HttpClient();
var request = new HttpRequestMessage
{
Method = HttpMethod.Get,
RequestUri = new Uri("https://eure-instanz.iw-erp.de/api/invoice/offeraccountingtypes"),
Headers =
{
{ "x-iw-jwt-token", "<TOKEN>" },
},
};
using (var response = await client.SendAsync(request))
{
response.EnsureSuccessStatusCode();
var body = await response.Content.ReadAsStringAsync();
Console.WriteLine(body);
}OkHttpClient client = new OkHttpClient();
Request request = new Request.Builder()
.url("https://eure-instanz.iw-erp.de/api/invoice/offeraccountingtypes")
.get()
.addHeader("x-iw-jwt-token", "<TOKEN>")
.build();
Response response = client.newCall(request).execute();package main
import (
"fmt"
"net/http"
"io"
)
func main() {
url := "https://eure-instanz.iw-erp.de/api/invoice/offeraccountingtypes"
req, _ := http.NewRequest("GET", url, nil)
req.Header.Add("x-iw-jwt-token", "<TOKEN>")
res, _ := http.DefaultClient.Do(req)
defer res.Body.Close()
body, _ := io.ReadAll(res.Body)
fmt.Println(string(body))
}Dart mit dem Package iw_erp_api
import 'package:iw_erp_api/clients/offer_accounting_type_controller.dart';
import 'package:iw_erp_api/logic/iw_api_state.dart';
IwApiState().host = 'eure-instanz.iw-erp.de';
IwApiState().currentJwtApiToken = '<TOKEN>';
final result = await OfferAccountingTypeController.getAll();
if (result.success) {
print(result.data);
}[
{
"name": "Beispiel",
"type": "string",
"id": 42,
"cancelled_name": "Beispiel",
"number_description": "Text",
"conditions": "string",
"deleted": true
}
]OfferAccountingType neu anlegen
POST/api/invoice/offeraccountingtypes
Request-Body application/json
dataOfferAccountingTypeFelder anzeigen (7)
idintegerPrimärschlüssel des Angebots-Buchungstyps. Interne ID.
namestringPflichtName der Buchungsart.
cancelled_namestringName, der verwendet wird, wenn ein Angebot dieses Typs storniert wird.
typestringPflichtArt des Buchungstyps, zum Beispiel Angebot oder Vertrag.
conditionsstringAuf dem Angebot abgedruckte Bedingungen.
number_descriptionstringBeschreibung des Zahlenformats des Angebots.
deletedbooleanDie Buchungsart wird gelöscht.
Antworten
200OfferAccountingType neu anlegenOfferAccountingType
Felder anzeigen (7)
idintegerPrimärschlüssel des Angebots-Buchungstyps. Interne ID.
namestringPflichtName der Buchungsart.
cancelled_namestringName, der verwendet wird, wenn ein Angebot dieses Typs storniert wird.
typestringPflichtArt des Buchungstyps, zum Beispiel Angebot oder Vertrag.
conditionsstringAuf dem Angebot abgedruckte Bedingungen.
number_descriptionstringBeschreibung des Zahlenformats des Angebots.
deletedbooleanDie Buchungsart wird gelöscht.
curl --request POST \
--url https://eure-instanz.iw-erp.de/api/invoice/offeraccountingtypes \
--header 'content-type: application/json' \
--header 'x-iw-jwt-token: <TOKEN>' \
--data '
{
"data": {
"name": "Beispiel",
"type": "string",
"id": 42,
"cancelled_name": "Beispiel",
"number_description": "Text",
"conditions": "string"
}
}
'const options = {
method: 'POST',
headers: {'x-iw-jwt-token': '<TOKEN>', 'content-type': 'application/json'},
body: JSON.stringify({
data: {
name: 'Beispiel',
type: 'string',
id: 42,
cancelled_name: 'Beispiel',
number_description: 'Text',
conditions: 'string'
}
})
};
fetch('https://eure-instanz.iw-erp.de/api/invoice/offeraccountingtypes', options)
.then(res => res.json())
.then(res => console.log(res))
.catch(err => console.error(err));import requests
url = "https://eure-instanz.iw-erp.de/api/invoice/offeraccountingtypes"
payload = { "data": {
"name": "Beispiel",
"type": "string",
"id": 42,
"cancelled_name": "Beispiel",
"number_description": "Text",
"conditions": "string"
} }
headers = {
"x-iw-jwt-token": "<TOKEN>",
"content-type": "application/json"
}
response = requests.post(url, json=payload, headers=headers)
print(response.text)<?php
require_once('vendor/autoload.php');
$client = new \GuzzleHttp\Client();
$response = $client->request('POST', 'https://eure-instanz.iw-erp.de/api/invoice/offeraccountingtypes', [
'body' => '{"data":{"name":"Beispiel","type":"string","id":42,"cancelled_name":"Beispiel","number_description":"Text","conditions":"string"}}',
'headers' => [
'content-type' => 'application/json',
'x-iw-jwt-token' => '<TOKEN>',
],
]);
echo $response->getBody();using System.Net.Http.Headers;
var client = new HttpClient();
var request = new HttpRequestMessage
{
Method = HttpMethod.Post,
RequestUri = new Uri("https://eure-instanz.iw-erp.de/api/invoice/offeraccountingtypes"),
Headers =
{
{ "x-iw-jwt-token", "<TOKEN>" },
},
Content = new StringContent("{\"data\":{\"name\":\"Beispiel\",\"type\":\"string\",\"id\":42,\"cancelled_name\":\"Beispiel\",\"number_description\":\"Text\",\"conditions\":\"string\"}}")
{
Headers =
{
ContentType = new MediaTypeHeaderValue("application/json")
}
}
};
using (var response = await client.SendAsync(request))
{
response.EnsureSuccessStatusCode();
var body = await response.Content.ReadAsStringAsync();
Console.WriteLine(body);
}OkHttpClient client = new OkHttpClient();
MediaType mediaType = MediaType.parse("application/json");
RequestBody body = RequestBody.create(mediaType, "{\"data\":{\"name\":\"Beispiel\",\"type\":\"string\",\"id\":42,\"cancelled_name\":\"Beispiel\",\"number_description\":\"Text\",\"conditions\":\"string\"}}");
Request request = new Request.Builder()
.url("https://eure-instanz.iw-erp.de/api/invoice/offeraccountingtypes")
.post(body)
.addHeader("x-iw-jwt-token", "<TOKEN>")
.addHeader("content-type", "application/json")
.build();
Response response = client.newCall(request).execute();package main
import (
"fmt"
"strings"
"net/http"
"io"
)
func main() {
url := "https://eure-instanz.iw-erp.de/api/invoice/offeraccountingtypes"
payload := strings.NewReader("{\"data\":{\"name\":\"Beispiel\",\"type\":\"string\",\"id\":42,\"cancelled_name\":\"Beispiel\",\"number_description\":\"Text\",\"conditions\":\"string\"}}")
req, _ := http.NewRequest("POST", url, payload)
req.Header.Add("x-iw-jwt-token", "<TOKEN>")
req.Header.Add("content-type", "application/json")
res, _ := http.DefaultClient.Do(req)
defer res.Body.Close()
body, _ := io.ReadAll(res.Body)
fmt.Println(string(body))
}Dart mit dem Package iw_erp_api
import 'package:iw_erp_api/clients/offer_accounting_type_controller.dart';
import 'package:iw_erp_api/logic/iw_api_state.dart';
import 'package:iw_erp_api/model/offer_accounting_type.dart';
IwApiState().host = 'eure-instanz.iw-erp.de';
IwApiState().currentJwtApiToken = '<TOKEN>';
final result = await OfferAccountingTypeController.post(OfferAccountingType.fromJson({
"name": "Beispiel",
"type": "string",
"id": 42,
"cancelled_name": "Beispiel",
"number_description": "Text",
"conditions": "string"
}));
if (result.success) {
print(result.data);
}{
"name": "Beispiel",
"type": "string",
"id": 42,
"cancelled_name": "Beispiel",
"number_description": "Text",
"conditions": "string",
"deleted": true
}Einzelnen OfferAccountingType abrufen
GET/api/invoice/offeraccountingtypes/{identifier}
Pfad-Parameter
identifierPflichtstring |
Antworten
200Einzelnen OfferAccountingType abrufenOfferAccountingType
Felder anzeigen (7)
idintegerPrimärschlüssel des Angebots-Buchungstyps. Interne ID.
namestringPflichtName der Buchungsart.
cancelled_namestringName, der verwendet wird, wenn ein Angebot dieses Typs storniert wird.
typestringPflichtArt des Buchungstyps, zum Beispiel Angebot oder Vertrag.
conditionsstringAuf dem Angebot abgedruckte Bedingungen.
number_descriptionstringBeschreibung des Zahlenformats des Angebots.
deletedbooleanDie Buchungsart wird gelöscht.
curl --request GET \
--url https://eure-instanz.iw-erp.de/api/invoice/offeraccountingtypes/42 \
--header 'x-iw-jwt-token: <TOKEN>'const options = {method: 'GET', headers: {'x-iw-jwt-token': '<TOKEN>'}};
fetch('https://eure-instanz.iw-erp.de/api/invoice/offeraccountingtypes/42', options)
.then(res => res.json())
.then(res => console.log(res))
.catch(err => console.error(err));import requests
url = "https://eure-instanz.iw-erp.de/api/invoice/offeraccountingtypes/42"
headers = {"x-iw-jwt-token": "<TOKEN>"}
response = requests.get(url, headers=headers)
print(response.text)<?php
require_once('vendor/autoload.php');
$client = new \GuzzleHttp\Client();
$response = $client->request('GET', 'https://eure-instanz.iw-erp.de/api/invoice/offeraccountingtypes/42', [
'headers' => [
'x-iw-jwt-token' => '<TOKEN>',
],
]);
echo $response->getBody();using System.Net.Http.Headers;
var client = new HttpClient();
var request = new HttpRequestMessage
{
Method = HttpMethod.Get,
RequestUri = new Uri("https://eure-instanz.iw-erp.de/api/invoice/offeraccountingtypes/42"),
Headers =
{
{ "x-iw-jwt-token", "<TOKEN>" },
},
};
using (var response = await client.SendAsync(request))
{
response.EnsureSuccessStatusCode();
var body = await response.Content.ReadAsStringAsync();
Console.WriteLine(body);
}OkHttpClient client = new OkHttpClient();
Request request = new Request.Builder()
.url("https://eure-instanz.iw-erp.de/api/invoice/offeraccountingtypes/42")
.get()
.addHeader("x-iw-jwt-token", "<TOKEN>")
.build();
Response response = client.newCall(request).execute();package main
import (
"fmt"
"net/http"
"io"
)
func main() {
url := "https://eure-instanz.iw-erp.de/api/invoice/offeraccountingtypes/42"
req, _ := http.NewRequest("GET", url, nil)
req.Header.Add("x-iw-jwt-token", "<TOKEN>")
res, _ := http.DefaultClient.Do(req)
defer res.Body.Close()
body, _ := io.ReadAll(res.Body)
fmt.Println(string(body))
}Dart mit dem Package iw_erp_api
import 'package:iw_erp_api/clients/offer_accounting_type_controller.dart';
import 'package:iw_erp_api/logic/iw_api_state.dart';
IwApiState().host = 'eure-instanz.iw-erp.de';
IwApiState().currentJwtApiToken = '<TOKEN>';
final result = await OfferAccountingTypeController.get('42');
if (result.success) {
print(result.data);
}{
"name": "Beispiel",
"type": "string",
"id": 42,
"cancelled_name": "Beispiel",
"number_description": "Text",
"conditions": "string",
"deleted": true
}OfferAccountingType aktualisieren
PUT/api/invoice/offeraccountingtypes/{identifier}
Pfad-Parameter
identifierPflichtstring |
Request-Body application/json
dataOfferAccountingTypeFelder anzeigen (7)
idintegerPrimärschlüssel des Angebots-Buchungstyps. Interne ID.
namestringPflichtName der Buchungsart.
cancelled_namestringName, der verwendet wird, wenn ein Angebot dieses Typs storniert wird.
typestringPflichtArt des Buchungstyps, zum Beispiel Angebot oder Vertrag.
conditionsstringAuf dem Angebot abgedruckte Bedingungen.
number_descriptionstringBeschreibung des Zahlenformats des Angebots.
deletedbooleanDie Buchungsart wird gelöscht.
Antworten
200OfferAccountingType aktualisierenOfferAccountingType
Felder anzeigen (7)
idintegerPrimärschlüssel des Angebots-Buchungstyps. Interne ID.
namestringPflichtName der Buchungsart.
cancelled_namestringName, der verwendet wird, wenn ein Angebot dieses Typs storniert wird.
typestringPflichtArt des Buchungstyps, zum Beispiel Angebot oder Vertrag.
conditionsstringAuf dem Angebot abgedruckte Bedingungen.
number_descriptionstringBeschreibung des Zahlenformats des Angebots.
deletedbooleanDie Buchungsart wird gelöscht.
curl --request PUT \
--url https://eure-instanz.iw-erp.de/api/invoice/offeraccountingtypes/42 \
--header 'content-type: application/json' \
--header 'x-iw-jwt-token: <TOKEN>' \
--data '
{
"data": {
"name": "Beispiel",
"type": "string",
"id": 42,
"cancelled_name": "Beispiel",
"number_description": "Text",
"conditions": "string"
}
}
'const options = {
method: 'PUT',
headers: {'x-iw-jwt-token': '<TOKEN>', 'content-type': 'application/json'},
body: JSON.stringify({
data: {
name: 'Beispiel',
type: 'string',
id: 42,
cancelled_name: 'Beispiel',
number_description: 'Text',
conditions: 'string'
}
})
};
fetch('https://eure-instanz.iw-erp.de/api/invoice/offeraccountingtypes/42', options)
.then(res => res.json())
.then(res => console.log(res))
.catch(err => console.error(err));import requests
url = "https://eure-instanz.iw-erp.de/api/invoice/offeraccountingtypes/42"
payload = { "data": {
"name": "Beispiel",
"type": "string",
"id": 42,
"cancelled_name": "Beispiel",
"number_description": "Text",
"conditions": "string"
} }
headers = {
"x-iw-jwt-token": "<TOKEN>",
"content-type": "application/json"
}
response = requests.put(url, json=payload, headers=headers)
print(response.text)<?php
require_once('vendor/autoload.php');
$client = new \GuzzleHttp\Client();
$response = $client->request('PUT', 'https://eure-instanz.iw-erp.de/api/invoice/offeraccountingtypes/42', [
'body' => '{"data":{"name":"Beispiel","type":"string","id":42,"cancelled_name":"Beispiel","number_description":"Text","conditions":"string"}}',
'headers' => [
'content-type' => 'application/json',
'x-iw-jwt-token' => '<TOKEN>',
],
]);
echo $response->getBody();using System.Net.Http.Headers;
var client = new HttpClient();
var request = new HttpRequestMessage
{
Method = HttpMethod.Put,
RequestUri = new Uri("https://eure-instanz.iw-erp.de/api/invoice/offeraccountingtypes/42"),
Headers =
{
{ "x-iw-jwt-token", "<TOKEN>" },
},
Content = new StringContent("{\"data\":{\"name\":\"Beispiel\",\"type\":\"string\",\"id\":42,\"cancelled_name\":\"Beispiel\",\"number_description\":\"Text\",\"conditions\":\"string\"}}")
{
Headers =
{
ContentType = new MediaTypeHeaderValue("application/json")
}
}
};
using (var response = await client.SendAsync(request))
{
response.EnsureSuccessStatusCode();
var body = await response.Content.ReadAsStringAsync();
Console.WriteLine(body);
}OkHttpClient client = new OkHttpClient();
MediaType mediaType = MediaType.parse("application/json");
RequestBody body = RequestBody.create(mediaType, "{\"data\":{\"name\":\"Beispiel\",\"type\":\"string\",\"id\":42,\"cancelled_name\":\"Beispiel\",\"number_description\":\"Text\",\"conditions\":\"string\"}}");
Request request = new Request.Builder()
.url("https://eure-instanz.iw-erp.de/api/invoice/offeraccountingtypes/42")
.put(body)
.addHeader("x-iw-jwt-token", "<TOKEN>")
.addHeader("content-type", "application/json")
.build();
Response response = client.newCall(request).execute();package main
import (
"fmt"
"strings"
"net/http"
"io"
)
func main() {
url := "https://eure-instanz.iw-erp.de/api/invoice/offeraccountingtypes/42"
payload := strings.NewReader("{\"data\":{\"name\":\"Beispiel\",\"type\":\"string\",\"id\":42,\"cancelled_name\":\"Beispiel\",\"number_description\":\"Text\",\"conditions\":\"string\"}}")
req, _ := http.NewRequest("PUT", url, payload)
req.Header.Add("x-iw-jwt-token", "<TOKEN>")
req.Header.Add("content-type", "application/json")
res, _ := http.DefaultClient.Do(req)
defer res.Body.Close()
body, _ := io.ReadAll(res.Body)
fmt.Println(string(body))
}Dart mit dem Package iw_erp_api
import 'package:iw_erp_api/clients/offer_accounting_type_controller.dart';
import 'package:iw_erp_api/logic/iw_api_state.dart';
import 'package:iw_erp_api/model/offer_accounting_type.dart';
IwApiState().host = 'eure-instanz.iw-erp.de';
IwApiState().currentJwtApiToken = '<TOKEN>';
final result = await OfferAccountingTypeController.put(OfferAccountingType.fromJson({
"name": "Beispiel",
"type": "string",
"id": 42,
"cancelled_name": "Beispiel",
"number_description": "Text",
"conditions": "string"
}));
if (result.success) {
print(result.data);
}{
"name": "Beispiel",
"type": "string",
"id": 42,
"cancelled_name": "Beispiel",
"number_description": "Text",
"conditions": "string",
"deleted": true
}